
### Desc
---

> package podchecker by LT


### Usage
---

install
> `pip3 install podchecker`

upgrade
> `pip3 install --upgrade podchecker`

use package as executable script
> `python3 -m podchecker [-a <android-properties>] [-i <ios-podfile>] [-k <ios-podfile.lock>] -v <lastest-version-config> [-h]`


### Find
---

find out where packages are:
> `pip3 -V`
>> `pip 19.0.2 from /usr/local/lib/python3.7/site-packages/pip (python 3.7)`
